@@ -98,7 +98,9 @@ if($userinfo['change_serversettings'] == '1')
 			'<SSLPROTOCOLS>' => ($settings['system']['use_ssl'] == '1') ? 'imaps pop3s' : '',
 			'<CUSTOMER_TMP>' => ($settings['system']['mod_fcgid_tmpdir'] != '') ? makeCorrectDir($settings['system']['mod_fcgid_tmpdir']) : '/tmp/',
 			'<BASE_PATH>' => makeCorrectDir(dirname(__FILE__)),
-			'<BIND_CONFIG_PATH>' => makeCorrectDir($settings['system']['bindconf_directory'])
+			'<BIND_CONFIG_PATH>' => makeCorrectDir($settings['system']['bindconf_directory']),
+			'<WEBSERVER_RELOAD_CMD>' => $settings['system']['apachereload_command'],
+			'<CUSTOMER_LOGS>' => makeCorrectDir($settings['system']['logfiles_directory'])
 		);
 		$files = '';
 		$configpage = '';
