@@ -1985,7 +1985,7 @@ if(isFroxlorVersion('0.9.28-svn4')) {
 	updateToVersion('0.9.28-svn5');
 }
 
-if(isFroxlorVersion('0.9.28-svn5')) {
+if (isFroxlorVersion('0.9.28-svn5')) {
 	showUpdateStep("Updating from 0.9.28-svn5 to 0.9.28-svn6", true);
 	lastStepStatus(0);
 
@@ -2068,7 +2068,7 @@ if (isFroxlorVersion('0.9.28.1')) {
 	$fastcgiparams = $settings['nginx']['fastcgiparams'];
 	// check the faulty value explicitly
 	if ($fastcgiparams == '/etc/nginx/fastcgi_params/') {
-		$fastcgiparams = makeCorrectFile(substr(fastcgiparams,0,-1));
+		$fastcgiparams = makeCorrectFile(substr($fastcgiparams,0,-1));
 		$db->query("UPDATE TABLE `panel_settings` SET `value`='".$db->escape($fastcgiparams)."' WHERE `varname`='fastcgiparams';");
 	}
 	updateToVersion('0.9.29-dev1');
@@ -2092,19 +2092,19 @@ if (isFroxlorVersion('0.9.29-dev2')) {
 	showUpdateStep("Updating from 0.9.29-dev2 to 0.9.29-dev3", true);
 	lastStepStatus(0);
 
-	$system_afxrservers = isset($_POST['system_afxrservers']) ? trim($_POST['system_afxrservers']) : '';
-	if ($system_afxrservers != '') {
-		$axfrservers = explode(',', $system_afxrservers);
+	$system_axfrservers = isset($_POST['system_afxrservers']) ? trim($_POST['system_afxrservers']) : '';
+	if ($system_axfrservers != '') {
+		$axfrservers = explode(',', $system_axfrservers);
 		$newaxfrserver = array();
 		foreach ($axfrservers as $index => $axfrserver) {
 			if (validate_ip($axfrserver, true) !== false) {
 				$newaxfrserver[] = $axfrserver;
 			}
 		}
-		$system_afxrservers = implode(", ", $newaxfrserver);
+		$system_axfrservers = implode(", ", $newaxfrserver);
 	}
-	showUpdateStep("Inserting new setting for AFXR server", true);
-	$db->query("INSERT INTO `panel_settings` (`settinggroup`, `varname`, `value`) VALUES ('system', 'axfrservers', '".$db->escape($system_afxrservers)."');");
+	showUpdateStep("Inserting new setting for AXFR server", true);
+	$db->query("INSERT INTO `panel_settings` (`settinggroup`, `varname`, `value`) VALUES ('system', 'axfrservers', '".$db->escape($system_axfrservers)."');");
 	lastStepStatus(0);
 
 	updateToVersion('0.9.29-dev3');
@@ -2116,17 +2116,21 @@ if (isFroxlorVersion('0.9.29-dev3')) {
 
 	showUpdateStep("Adding new tables to database", true);
 	$db->query("CREATE TABLE IF NOT EXISTS `domain_ssl_settings` (
-	`id` int(5) NOT NULL auto_increment,
-	`domainid` int(11) NOT NULL,
-	`ssl_cert_file` text NOT NULL,
-	`ssl_key_file` text NOT NULL,
-	`ssl_ca_file` text NOT NULL,
-	`ssl_cert_chainfile` text NOT NULL,
-	PRIMARY KEY  (`id`)
+			`id` int(5) NOT NULL auto_increment,
+			`domainid` int(11) NOT NULL,
+			`ssl_cert_file` text NOT NULL,
+			`ssl_key_file` text NOT NULL,
+			`ssl_ca_file` text NOT NULL,
+			`ssl_cert_chainfile` text NOT NULL,
+			PRIMARY KEY  (`id`)
 	) ENGINE=MyISAM CHARSET=utf8 COLLATE=utf8_general_ci;");
 	lastStepStatus(0);
 
-	$system_customersslpath = isset($_POST['system_customersslpath']) ? makeCorrectDir($_POST['system_customersslpath']) : '/etc/apache2/ssl/';
+	$system_customersslpath = isset($_POST['system_customersslpath']) ? makeCorrectDir($_POST['system_customersslpath']) : '/etc/ssl/froxlor-custom/';
+	if (trim($system_customersslpath) == '/') {
+		// prevent users from specifying nonsense here
+		$system_customersslpath = '/etc/ssl/froxlor-custom/';
+	}
 	$db->query("INSERT INTO `panel_settings` (`settinggroup`, `varname`, `value`) VALUES ('system', 'customer_ssl_path', '".$db->escape($system_customersslpath)."');");
 	updateToVersion('0.9.29-dev4');
 }
@@ -2155,3 +2159,121 @@ if (isFroxlorVersion('0.9.29-rc1')) {
 	lastStepStatus(0);
 	updateToVersion('0.9.29');
 }
+
+if (isFroxlorVersion('0.9.29')) {
+	showUpdateStep("Updating from 0.9.29 to 0.9.29.1-dev1", true);
+	lastStepStatus(0);
+
+	showUpdateStep("Adding new ip to domain - mapping-table");
+	$db->query("DROP TABLE IF EXISTS `panel_domaintoip`;");
+	$sql = "CREATE TABLE `".TABLE_DOMAINTOIP."` (
+			`id_domain` int(11) unsigned NOT NULL,
+			`id_ipandports` int(11) unsigned NOT NULL,
+			PRIMARY KEY (`id_domain`, `id_ipandports`)
+			) ENGINE=MyISAM ;";
+	$db->query($sql);
+	lastStepStatus(0);
+
+	showUpdateStep("Convert old domain to ip - mappings");
+	$result = $db->query("SELECT `id`, `ipandport`, `ssl_ipandport`, `ssl_redirect`, `parentdomainid` FROM `" . TABLE_PANEL_DOMAINS . "`;");
+
+	while ($row = $db->fetch_array($result)) {
+		if ((int)$row['ipandport'] != 0) {
+			$db->query("INSERT INTO `".TABLE_DOMAINTOIP."` SET
+					`id_domain` = " . (int)$row['id'] . ",
+					`id_ipandports` = " . (int)$row['ipandport']);
+		}
+		if ((int)$row['ssl_ipandport'] != 0) {
+			$db->query("INSERT INTO `".TABLE_DOMAINTOIP."` SET
+					`id_domain` = " . (int)$row['id'] . ",
+					`id_ipandports` = " . (int)$row['ssl_ipandport']);
+		}
+		// Subdomains also have ssl ports if the parent has
+		elseif ((int)$row['ssl_ipandport'] == 0
+				&& (int)$row['ssl_redirect'] != 0
+				&& (int)$row['parentdomainid'] != 0
+		) {
+			$db->query("INSERT INTO `".TABLE_DOMAINTOIP."` SET
+					`id_domain` = " . (int)$row['id'] . ",
+					`id_ipandports` = (
+					SELECT `ssl_ipandport` FROM `" . TABLE_PANEL_DOMAINS . "`
+					WHERE `id` = '".(int)$row['parentdomainid']."');"
+			);
+		}
+	}
+	lastStepStatus(0);
+
+	showUpdateStep("Updating table layouts");
+	$db->query("ALTER TABLE `".TABLE_PANEL_DOMAINS."` DROP `ipandport`;");
+	$db->query("ALTER TABLE `".TABLE_PANEL_DOMAINS."` DROP `ssl`;");
+	$db->query("ALTER TABLE `".TABLE_PANEL_DOMAINS."` DROP `ssl_ipandport`;");
+	lastStepStatus(0);
+
+	updateToVersion('0.9.29.1-dev1');
+}
+
+if (isFroxlorVersion('0.9.29.1-dev1')) {
+	showUpdateStep("Updating from 0.9.29.1-dev1 to 0.9.29.1-dev2", true);
+	lastStepStatus(0);
+
+	showUpdateStep("Updating table layouts and contents");
+	$db->query("ALTER TABLE `".TABLE_MAIL_USERS."` ADD `mboxsize` bigint(30) NOT NULL default '0' AFTER `imap`;");
+	$db->query("INSERT INTO `cronjobs_run` SET `module` = 'froxlor/core', `cronfile` = 'cron_mailboxsize.php', `interval` = '6 HOUR', `isactive` = '1', `desc_lng_key` = 'cron_mailboxsize';");
+	lastStepStatus(0);
+
+	updateToVersion('0.9.29.1-dev2');
+}
+
+if (isFroxlorVersion('0.9.29.1-dev2')) {
+	showUpdateStep("Updating from 0.9.29.1-dev2 to 0.9.29.1-dev3", true);
+	lastStepStatus(0);
+
+	showUpdateStep("Removing old logrotate settings");
+	$db->query("DELETE FROM `panel_settings` WHERE `varname` = 'logrotate_enabled';");
+	$db->query("DELETE FROM `panel_settings` WHERE `varname` = 'logrotate_binary';");
+	$db->query("DELETE FROM `panel_settings` WHERE `varname` = 'logrotate_interval';");
+	$db->query("DELETE FROM `panel_settings` WHERE `varname` = 'logrotate_keep';");
+	lastStepStatus(0);
+
+	updateToVersion('0.9.29.1-dev3');
+}
+
+if (isFroxlorVersion('0.9.29.1-dev3')) {
+	showUpdateStep("Updating from 0.9.29.1-dev3 to 0.9.29.1-dev4", true);
+	lastStepStatus(0);
+
+	// If you upgraded from SysCP the edit_billingdata field has been
+	// removed in one of the first upgrades to froxlor. Sadly, one field
+	// remained in the install.sql so  we remove it now if it exists
+	$bd_exists = $db->query("SHOW COLUMNS FROM `".TABLE_PANEL_ADMINS."` LIKE 'edit_billingdata';");
+	if ($db->num_rows() > 0) {
+		showUpdateStep("Removing old billing-field from admin-users");
+		$db->query("ALTER TABLE `".TABLE_PANEL_ADMINS."` DROP `edit_billingdata`");
+		lastStepStatus(0);
+	}
+
+	updateToVersion('0.9.29.1-dev4');
+}
+
+if (isFroxlorVersion('0.9.29.1-dev4')) {
+	showUpdateStep("Updating from 0.9.29.1-dev4 to 0.9.30-dev1", true);
+	lastStepStatus(0);
+	updateToVersion('0.9.30-dev1');
+}
+
+if (isFroxlorVersion('0.9.30-dev1')) {
+	showUpdateStep("Updating from 0.9.30-dev1 to 0.9.30-rc1", true);
+	lastStepStatus(0);
+	updateToVersion('0.9.30-rc1');
+}
+
+if (isFroxlorVersion('0.9.30-rc1')) {
+	showUpdateStep("Updating from 0.9.30-rc1 to 0.9.30 final", true);
+	lastStepStatus(0);
+
+	showUpdateStep("Adding ssl-cipher-list setting");
+	$db->query("INSERT INTO `panel_settings` SET `settinggroup` = 'system', `varname` = 'ssl_cipher_list', `value` = 'ECDHE-RSA-AES128-SHA256:AES128-GCM-SHA256:RC4:HIGH:!MD5:!aNULL:!EDH'");
+	lastStepStatus(0);
+
+	updateToVersion('0.9.30');
+}
