@@ -12,7 +12,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Functions
- * @version    $Id$
+ *
  */
 
 /*
@@ -27,7 +27,7 @@
  */
 function customerHasPerlEnabled($cid = 0)
 {
-	global $db;
+	global $db, $theme;
 
 	if($cid > 0)
 	{
