@@ -12,7 +12,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Functions
- * @version    $Id$
+ *
  */
 
 /**
@@ -22,7 +22,7 @@
  */
 function getPhpConfigs()
 {
-	global $db;
+	global $db, $theme;
 	
 	$query = 'SELECT * FROM `' . TABLE_PANEL_PHPCONFIGS . '` ';
 	$result = $db->query($query, false, true);
