@@ -221,6 +221,11 @@ return array (
 					'label' => $lng['admin']['serversettings'],
 					'required_resources' => 'change_serversettings',
 				),
+				array (
+					'url' => 'admin_settings.php?page=phpinfo',
+					'label' => $lng['admin']['phpinfo'],
+					'required_resources' => 'change_serversettings',
+				),
 				array (
 					'url' => 'admin_ipsandports.php?page=ipsandports',
 					'label' => $lng['admin']['ipsandports']['ipsandports'],
