@@ -56,6 +56,7 @@ class apache
 		$this->debugHandler = $debugHandler;
 		$this->idnaConvert = $idnaConvert;
 		$this->settings = $settings;
+
 	}
 
 	protected function getDB()
@@ -144,9 +145,11 @@ class apache
 				if ($this->settings['defaultwebsrverrhandler']['err' . $statusCode] != '') {
 					$defhandler = $this->settings['defaultwebsrverrhandler']['err' . $statusCode];
 					if (!validateUrl($defhandler)) {
-						$defhandler = makeCorrectFile($defhandler);
+						if (substr($defhandler, 0, 1) != '"' && substr($defhandler, -1, 1) != '"') {
+							$defhandler = '"'.makeCorrectFile($defhandler).'"';
+						}
 					}
-					$this->virtualhosts_data[$vhosts_filename] .= 'ErrorDocument ' . $statusCode . ' "' . $defhandler . '"'."\n";
+					$this->virtualhosts_data[$vhosts_filename] .= 'ErrorDocument ' . $statusCode . ' ' . $defhandler . "\n";
 				}
 			}
 		}
@@ -219,20 +222,40 @@ class apache
 						$this->virtualhosts_data[$vhosts_filename] .= '  SuexecUserGroup "' . $this->settings['system']['mod_fcgid_httpuser'] . '" "' . $this->settings['system']['mod_fcgid_httpgroup'] . '"' . "\n";
 						$this->virtualhosts_data[$vhosts_filename] .= '  ScriptAlias /php/ ' . $configdir . "\n";
 					} else {
+						$domain = array(
+							'id' => 'none',
+							'domain' => $this->settings['system']['hostname'],
+							'adminid' => 1, /* first admin-user (superadmin) */
+							'mod_fcgid_starter' => -1,
+							'mod_fcgid_maxrequests' => -1,
+							'guid' => $this->settings['phpfpm']['vhost_httpuser'],
+							'openbasedir' => 0,
+							'email' => $this->settings['panel']['adminmail'],
+							'loginname' => 'froxlor.panel',
+							'documentroot' => $mypath
+						);
+						$php = new phpinterface($this->getDB(), $this->settings, $domain);
+						$phpconfig = $php->getPhpConfig($this->settings['system']['mod_fcgid_defaultini_ownvhost']);
+
 						$starter_filename = makeCorrectFile($configdir . '/php-fcgi-starter');
 						$this->virtualhosts_data[$vhosts_filename] .= '  SuexecUserGroup "' . $this->settings['system']['mod_fcgid_httpuser'] . '" "' . $this->settings['system']['mod_fcgid_httpgroup'] . '"' . "\n";
-						$this->virtualhosts_data[$vhosts_filename] .= '  <Directory "' . $mypath . '">' . "\n";
-						$this->virtualhosts_data[$vhosts_filename] .= '    AddHandler fcgid-script .php' . "\n";
-						$this->virtualhosts_data[$vhosts_filename] .= '    FcgidWrapper ' . $starter_filename . ' .php' . "\n";
-						$this->virtualhosts_data[$vhosts_filename] .= '    Options +ExecCGI' . "\n";
+						$this->virtualhosts_data[$vhosts_filename].= '  <Directory "' . $mypath . '">' . "\n";
+						$file_extensions = explode(' ', $phpconfig['file_extensions']);
+						$this->virtualhosts_data[$vhosts_filename].= '    <FilesMatch "\.(' . implode('|', $file_extensions) . ')$">' . "\n";
+						$this->virtualhosts_data[$vhosts_filename].= '      AddHandler fcgid-script .php' . "\n";
+						foreach ($file_extensions as $file_extension) {
+							$this->virtualhosts_data[$vhosts_filename].= '      FcgidWrapper ' . $starter_filename . ' .' . $file_extension . "\n";
+						}
+						$this->virtualhosts_data[$vhosts_filename].= '      Options +ExecCGI' . "\n";
+						$this->virtualhosts_data[$vhosts_filename].= '    </FilesMatch>' . "\n";
 						// >=apache-2.4 enabled?
 						if ($this->settings['system']['apache24'] == '1') {
-							$this->virtualhosts_data[$vhosts_filename] .= '    Require all granted' . "\n";
+							$this->virtualhosts_data[$vhosts_filename].= '    Require all granted' . "\n";
 						} else {
-							$this->virtualhosts_data[$vhosts_filename] .= '    Order allow,deny' . "\n";
-							$this->virtualhosts_data[$vhosts_filename] .= '    allow from all' . "\n";
+							$this->virtualhosts_data[$vhosts_filename].= '    Order allow,deny' . "\n";
+							$this->virtualhosts_data[$vhosts_filename].= '    allow from all' . "\n";
 						}
-						$this->virtualhosts_data[$vhosts_filename] .= '  </Directory>' . "\n";
+						$this->virtualhosts_data[$vhosts_filename].= '  </Directory>' . "\n";
 					}
 				}
 				// create php-fpm <Directory>-Part (config is created in apache_fcgid)
@@ -251,16 +274,19 @@ class apache
 					);
 
 					$php = new phpinterface($this->getDB(), $this->settings, $domain);
-					$this->virtualhosts_data[$vhosts_filename] .= '  SuexecUserGroup "' . $this->settings['phpfpm']['vhost_httpuser'] . '" "' . $this->settings['phpfpm']['vhost_httpgroup'] . '"' . "\n";
-					$srvName = 'fpm.external';
+					$phpconfig = $php->getPhpConfig($this->settings['phpfpm']['vhost_defaultini']);
+					$srvName = substr(md5($ipport),0,4).'.fpm.external';
 					if ($row_ipsandports['ssl']) {
-						$srvName = 'ssl-fpm.external';
+						$srvName = substr(md5($ipport),0,4).'.ssl-fpm.external';
 					}
-					$this->virtualhosts_data[$vhosts_filename] .= '  FastCgiExternalServer ' . $php->getInterface()->getAliasConfigDir() . $srvName .' -socket ' . $php->getInterface()->getSocketFile() . ' -user ' . $this->settings['phpfpm']['vhost_httpuser'] . ' -group ' . $this->settings['phpfpm']['vhost_httpgroup'] . " -idle-timeout " . $this->settings['phpfpm']['idle_timeout'] . "\n";
+					$this->virtualhosts_data[$vhosts_filename] .= '  FastCgiExternalServer ' . $php->getInterface()->getAliasConfigDir() . $srvName .' -socket ' . $php->getInterface()->getSocketFile() . ' -idle-timeout ' . $this->settings['phpfpm']['idle_timeout'] . "\n";
 					$this->virtualhosts_data[$vhosts_filename] .= '  <Directory "' . $mypath . '">' . "\n";
-					$this->virtualhosts_data[$vhosts_filename] .= '    AddHandler php5-fastcgi .php'. "\n";
-					$this->virtualhosts_data[$vhosts_filename] .= '    Action php5-fastcgi /fastcgiphp' . "\n";
-					$this->virtualhosts_data[$vhosts_filename] .= '    Options +ExecCGI' . "\n";
+					$file_extensions = explode(' ', $phpconfig['file_extensions']);
+					$this->virtualhosts_data[$vhosts_filename] .= '   <FilesMatch "\.(' . implode('|', $file_extensions) . ')$">' . "\n";
+					$this->virtualhosts_data[$vhosts_filename] .= '     AddHandler php5-fastcgi .php'. "\n";
+					$this->virtualhosts_data[$vhosts_filename] .= '     Action php5-fastcgi /fastcgiphp' . "\n";
+					$this->virtualhosts_data[$vhosts_filename].= '      Options +ExecCGI' . "\n";
+					$this->virtualhosts_data[$vhosts_filename].= '    </FilesMatch>' . "\n";
 					// >=apache-2.4 enabled?
 					if ($this->settings['system']['apache24'] == '1') {
 						$this->virtualhosts_data[$vhosts_filename] .= '    Require all granted' . "\n";
@@ -313,7 +339,8 @@ class apache
 						$this->virtualhosts_data[$vhosts_filename] .= ' SSLEngine On' . "\n";
 						// this makes it more secure, thx to Marcel (08/2013)
 						$this->virtualhosts_data[$vhosts_filename] .= ' SSLHonorCipherOrder On' . "\n";
-						$this->virtualhosts_data[$vhosts_filename] .= ' SSLCipherSuite ECDHE-RSA-AES128-SHA256:AES128-GCM-SHA256:RC4:HIGH:!MD5:!aNULL:!EDH' . "\n";
+						$this->virtualhosts_data[$vhosts_filename] .= ' SSLCipherSuite ' . $this->settings['system']['ssl_cipher_list'] . "\n";
+						$this->virtualhosts_data[$vhosts_filename] .= ' SSLVerifyDepth 10' . "\n";
 						$this->virtualhosts_data[$vhosts_filename] .= ' SSLCertificateFile ' . makeCorrectFile($row_ipsandports['ssl_cert_file']) . "\n";
 
 						if ($row_ipsandports['ssl_key_file'] != '') {
@@ -584,53 +611,90 @@ class apache
 	protected function getVhostContent($domain, $ssl_vhost = false)
 	{
 		if ($ssl_vhost === true
-		   && $domain['ssl'] != '1'
+		    && ($domain['ssl_redirect'] != '1' 
+		    && $domain['ssl'] != '1')
 		) {
 			return '';
 		}
 
+		$query = "SELECT * FROM `".TABLE_PANEL_IPSANDPORTS."` `i`, `".TABLE_DOMAINTOIP."` `dip` 
+			WHERE dip.id_domain = '".(int)$domain['id']."' AND i.id = dip.id_ipandports ";
+
 		if ($ssl_vhost === true
-		   && $domain['ssl'] == '1'
+				&& ($domain['ssl'] == '1' || $domain['ssl_redirect'] == '1')
 		) {
-			$query = "SELECT * FROM " . TABLE_PANEL_IPSANDPORTS . " WHERE `id`='" . $domain['ssl_ipandport'] . "'";
+			// by ordering by cert-file the row with filled out SSL-Fields will be shown last, thus it is enough to fill out 1 set of SSL-Fields
+			$query .= "AND i.ssl = '1' ORDER BY i.ssl_cert_file ASC;";
 		} else {
-			$query = "SELECT * FROM " . TABLE_PANEL_IPSANDPORTS . " WHERE `id`='" . $domain['ipandport'] . "'";
+			$query .= "AND i.ssl = '0';";
 		}
 
-		$ipandport = $this->db->query_first($query);
-		$domain['ip'] = $ipandport['ip'];
-		$domain['port'] = $ipandport['port'];
-		$domain['ssl_cert_file'] = $ipandport['ssl_cert_file'];
-		$domain['ssl_key_file'] = $ipandport['ssl_key_file'];
-		$domain['ssl_ca_file'] = $ipandport['ssl_ca_file'];
-		// #418
-		$domain['ssl_cert_chainfile'] = $ipandport['ssl_cert_chainfile'];
+		$vhost_content = '';
+		$result = $this->db->query($query);
 
-		// SSL STUFF
-		$dssl = new DomainSSL($this->settings, $this->db);
-		// this sets the ssl-related array-indices in the $domain array
-		// if the domain has customer-defined ssl-certificates
-		$dssl->setDomainSSLFilesArray($domain);
+		$ipportlist = '';
+		$_vhost_content = '';
+		while ($ipandport = $this->db->fetch_array($result)) {
 
-		if (filter_var($domain['ip'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV6)) {
-			$ipport = '[' . $domain['ip'] . ']:' . $domain['port'];
-		} else {
-			$ipport = $domain['ip'] . ':' . $domain['port'];
+			$ipport = '';
+			$domain['ip'] = $ipandport['ip'];
+			$domain['port'] = $ipandport['port'];
+			if ($domain['ssl'] == '1') {
+				$domain['ssl_cert_file'] = $ipandport['ssl_cert_file'];
+				$domain['ssl_key_file'] = $ipandport['ssl_key_file'];
+				$domain['ssl_ca_file'] = $ipandport['ssl_ca_file'];
+				$domain['ssl_cert_chainfile'] = $ipandport['ssl_cert_chainfile'];
+
+				// SSL STUFF
+				$dssl = new DomainSSL($this->settings, $this->db);
+				// this sets the ssl-related array-indices in the $domain array
+				// if the domain has customer-defined ssl-certificates
+				$dssl->setDomainSSLFilesArray($domain);
+			}
+
+			if (filter_var($domain['ip'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV6)) {
+				$ipport = '['.$domain['ip'].']:'.$domain['port']. ' ';
+			} else {
+				$ipport = $domain['ip'].':'.$domain['port'].' ';
+			}
+
+			if ($ipandport['default_vhostconf_domain'] != '') {
+				$_vhost_content .= $ipandport['default_vhostconf_domain'] . "\n";
+			}
+			$ipportlist .= $ipport;
 		}
 
-		$vhost_content = '<VirtualHost ' . $ipport . '>' . "\n";
-		$vhost_content .= $this->getServerNames($domain);
+		$vhost_content .= '<VirtualHost ' . trim($ipportlist) . '>' . "\n";
+		$vhost_content.= $this->getServerNames($domain);
 
-		if ($ssl_vhost == false
+		if(($ssl_vhost == false
 		   && $domain['ssl'] == '1'
-		   && $domain['ssl_redirect'] == '1'
+		   && $domain['ssl_redirect'] == '1')
 		) {
-			$domain['documentroot'] = 'https://' . $domain['domain'] . '/';
+			// We must not check if our port differs from port 443,
+			// but if there is a destination-port != 443
+			$_sslport = '';
+			// This returns the first port that is != 443 with ssl enabled, if any
+			// ordered by ssl-certificate (if any) so that the ip/port combo
+			// with certificate is used
+			$ssldestport = $this->db->query_first(
+				"SELECT `ip`.`port` FROM ".TABLE_PANEL_IPSANDPORTS." `ip`
+				LEFT JOIN `".TABLE_DOMAINTOIP."` `dip` ON (`ip`.`id` = `dip`.`id_ipandports`)
+				WHERE `dip`.`id_domain` = '".(int)$domain['id']."'
+				AND `ip`.`ssl` = '1'  AND `ip`.`port` != 443
+				ORDER BY `ip`.`ssl_cert_file` DESC, `ip`.`port` LIMIT 1;"
+			);
+
+			if ($ssldestport['port'] != '') {
+				$_sslport = ":".$ssldestport['port'];
+			}
+
+			$domain['documentroot'] = 'https://' . $domain['domain'] . $_sslport . '/';
 		}
-		
+
 		if ($ssl_vhost === true
-		   && $domain['ssl'] == '1'
-		   && $this->settings['system']['use_ssl'] == '1'
+			&& $domain['ssl'] == '1'
+			&& $this->settings['system']['use_ssl'] == '1'
 		) {
 			if ($domain['ssl_cert_file'] == '') {
 				$domain['ssl_cert_file'] = $this->settings['system']['ssl_cert_file'];
@@ -644,7 +708,6 @@ class apache
 				$domain['ssl_ca_file'] = $this->settings['system']['ssl_ca_file'];
 			}
 
-			// #418
 			if ($domain['ssl_cert_chainfile'] == '') {
 				$domain['ssl_cert_chainfile'] = $this->settings['system']['ssl_cert_chainfile'];
 			}
@@ -653,7 +716,8 @@ class apache
 				$vhost_content .= '  SSLEngine On' . "\n";
 				// this makes it more secure, thx to Marcel (08/2013)
 				$vhost_content .= '  SSLHonorCipherOrder On' . "\n";
-				$vhost_content .= '  SSLCipherSuite ECDHE-RSA-AES128-SHA256:AES128-GCM-SHA256:RC4:HIGH:!MD5:!aNULL:!EDH' . "\n";
+				$vhost_content .= '  SSLCipherSuite ' . $this->settings['system']['ssl_cipher_list'] . "\n";
+				$vhost_content .= '  SSLVerifyDepth 10' . "\n";
 				$vhost_content .= '  SSLCertificateFile ' . makeCorrectFile($domain['ssl_cert_file']) . "\n";
 
 				if ($domain['ssl_key_file'] != '') {
@@ -664,7 +728,6 @@ class apache
 					$vhost_content .= '  SSLCACertificateFile ' . makeCorrectFile($domain['ssl_ca_file']) . "\n";
 				}
 
-				// #418
 				if ($domain['ssl_cert_chainfile'] != '') {
 					$vhost_content .= '  SSLCertificateChainFile ' . makeCorrectFile($domain['ssl_cert_chainfile']) . "\n";
 				}
@@ -690,7 +753,9 @@ class apache
 
 			$code = getDomainRedirectCode($domain['id']);
 			$vhost_content .= '  Redirect '.$code.' / ' . $this->idnaConvert->encode($domain['documentroot']) . "\n";
+
 		} else {
+
 			mkDirWithCorrectOwnership($domain['customerroot'], $domain['documentroot'], $domain['guid'], $domain['guid'], true, true);
 			$vhost_content .= $this->getWebroot($domain);
 			if ($this->_deactivated == false) {
@@ -703,8 +768,8 @@ class apache
 				$vhost_content .= $domain['specialsettings'] . "\n";
 			}
 
-			if ($ipandport['default_vhostconf_domain'] != '') {
-				$vhost_content .= $ipandport['default_vhostconf_domain'] . "\n";
+			if ($_vhost_content != '') {
+				$vhost_content .= $_vhost_content;
 			}
 
 			if ($this->settings['system']['default_vhostconf'] != '') {
@@ -713,6 +778,7 @@ class apache
 		}
 
 		$vhost_content .= '</VirtualHost>' . "\n";
+
 		return $vhost_content;
 	}
 
@@ -721,8 +787,32 @@ class apache
 	 */
 	public function createVirtualHosts()
 	{
-		$result_domains = $this->db->query("SELECT `d`.*, `pd`.`domain` AS `parentdomain`, `c`.`loginname`, `d`.`phpsettingid`, `c`.`adminid`, `c`.`guid`, `c`.`email`, `c`.`documentroot` AS `customerroot`, `c`.`deactivated`, `c`.`phpenabled` AS `phpenabled`, `d`.`mod_fcgid_starter`, `d`.`mod_fcgid_maxrequests` FROM `" . TABLE_PANEL_DOMAINS . "` `d` LEFT JOIN `" . TABLE_PANEL_CUSTOMERS . "` `c` USING(`customerid`) " . "LEFT JOIN `" . TABLE_PANEL_DOMAINS . "` `pd` ON (`pd`.`id` = `d`.`parentdomainid`) " . "WHERE `d`.`aliasdomain` IS NULL AND `d`.`email_only` <> 1 ORDER BY `d`.`parentdomainid` DESC, `d`.`iswildcarddomain`, `d`.`domain` ASC");
+		//$result_domains = $this->db->query("SELECT `d`.*, `pd`.`domain` AS `parentdomain`, `c`.`loginname`, `d`.`phpsettingid`, `c`.`adminid`, `c`.`guid`, `c`.`email`, `c`.`documentroot` AS `customerroot`, `c`.`deactivated`, `c`.`phpenabled` AS `phpenabled`, `d`.`mod_fcgid_starter`, `d`.`mod_fcgid_maxrequests` FROM `" . TABLE_PANEL_DOMAINS . "` `d` LEFT JOIN `" . TABLE_PANEL_CUSTOMERS . "` `c` USING(`customerid`) " . "LEFT JOIN `" . TABLE_PANEL_DOMAINS . "` `pd` ON (`pd`.`id` = `d`.`parentdomainid`) " . "WHERE `d`.`aliasdomain` IS NULL AND `d`.`email_only` <> 1 ORDER BY `d`.`parentdomainid` DESC, `d`.`iswildcarddomain`, `d`.`domain` ASC");
+		$query = "SELECT `d`.*, `pd`.`domain` AS `parentdomain`, `c`.`loginname`,
+			`d`.`phpsettingid`, `c`.`adminid`, `c`.`guid`, `c`.`email`, 
+			`c`.`documentroot` AS `customerroot`, `c`.`deactivated`,
+			`c`.`phpenabled` AS `phpenabled`, `d`.`mod_fcgid_starter`, 
+			`d`.`mod_fcgid_maxrequests`, `p`.`ssl` AS `ssl`,
+			`p`.`ssl_cert_file`, `p`.`ssl_key_file`, `p`.`ssl_ca_file`, `p`.`ssl_cert_chainfile` 
+			  FROM `".TABLE_PANEL_DOMAINS."` `d`
+      
+			  LEFT JOIN `".TABLE_PANEL_CUSTOMERS."` `c` USING(`customerid`) 
+			  LEFT JOIN `".TABLE_PANEL_DOMAINS."` `pd` ON (`pd`.`id` = `d`.`parentdomainid`)
+			  
+			  INNER JOIN (
+			    SELECT * FROM ( 
+			      SELECT `di`.`id_domain` , `p`.`ssl`, `p`.`ssl_cert_file`, `p`.`ssl_key_file`, `p`.`ssl_ca_file`, `p`.`ssl_cert_chainfile` 
+			      FROM `".TABLE_DOMAINTOIP."` `di` , `".TABLE_PANEL_IPSANDPORTS."` `p` 
+			      WHERE `p`.`id` = `di`.`id_ipandports` 
+			      ORDER BY `p`.`ssl` DESC 
+			    ) AS my_table_tmp
+			    GROUP BY `id_domain`
+			  ) AS p ON p.`id_domain` = `d`.`id`
+			  
+			  WHERE `d`.`aliasdomain` IS NULL 
+			  ORDER BY `d`.`parentdomainid` DESC, `d`.`iswildcarddomain`, `d`.`domain` ASC;";
 
+		$result_domains = $this->db->query($query);
 		while ($domain = $this->db->fetch_array($result_domains)) {
 			fwrite($this->debugHandler, '  apache::createVirtualHosts: creating vhost container for domain ' . $domain['id'] . ', customer ' . $domain['loginname'] . "\n");
 			$this->logger->logAction(CRON_ACTION, LOG_INFO, 'creating vhost container for domain ' . $domain['id'] . ', customer ' . $domain['loginname']);
@@ -732,11 +822,12 @@ class apache
 			$this->virtualhosts_data[$vhosts_filename] = '# Domain ID: ' . $domain['id'] . ' - CustomerID: ' . $domain['customerid'] . ' - CustomerLogin: ' . $domain['loginname'] . "\n";
 
 			if ($domain['deactivated'] != '1'
-			   || $this->settings['system']['deactivateddocroot'] != ''
+				|| $this->settings['system']['deactivateddocroot'] != ''
 			) {
-				$this->virtualhosts_data[$vhosts_filename].= $this->getVhostContent($domain);
+				// Create vhost without ssl
+				$this->virtualhosts_data[$vhosts_filename].= $this->getVhostContent($domain, false);
 
-				if ($domain['ssl'] == '1') {
+				if ($domain['ssl'] == '1' || $domain['ssl_redirect'] == '1') {
 					// Adding ssl stuff if enabled
 					$vhosts_filename_ssl = $this->getVhostFilename($domain, true);
 					$this->virtualhosts_data[$vhosts_filename_ssl] = '# Domain ID: ' . $domain['id'] . ' (SSL) - CustomerID: ' . $domain['customerid'] . ' - CustomerLogin: ' . $domain['loginname'] . "\n";
@@ -840,9 +931,11 @@ class apache
 					) {
 						$defhandler = $row_diroptions['error' . $statusCode . 'path'];
 						if (!validateUrl($defhandler)) {
-							$defhandler = makeCorrectFile($defhandler);
+							if (substr($defhandler, 0, 1) != '"' && substr($defhandler, -1, 1) != '"') {
+								$defhandler = '"'.makeCorrectFile($defhandler).'"';
+							}
 						}
-						$this->diroptions_data[$diroptions_filename].= '  ErrorDocument ' . $statusCode . ' "' . $defhandler. '"' . "\n";
+						$this->diroptions_data[$diroptions_filename].= '  ErrorDocument ' . $statusCode . ' ' . $defhandler . "\n";
 					}
 				}
 
@@ -1048,7 +1141,6 @@ class apache
 					fwrite($vhosts_file_handler, $vhosts_file);
 					fclose($vhosts_file_handler);
 				}
-
 			}
 		}
 	}
