@@ -14,12 +14,12 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id$
+ *
  */
 
 function awstatsDoSingleDomain($domain, $outputdir)
 {
-	global $cronlog, $settings;
+	global $cronlog, $settings, $theme;
 	$returnval = 0;
 
 	$domainconfig = makeCorrectFile($settings['system']['awstats_conf'].'/awstats.' . $domain . '.conf');
@@ -104,7 +104,7 @@ function awstatsDoSingleDomain($domain, $outputdir)
 
 function callAwstatsGetTraffic($customerid, $outputdir, $usersdomainlist)
 {
-	global $settings, $db, $cronlog;
+	global $settings, $db, $cronlog, $theme;
 	$returnval = 0;
 
 	foreach($usersdomainlist as $domainid => $singledomain)
@@ -156,7 +156,7 @@ function callAwstatsGetTraffic($customerid, $outputdir, $usersdomainlist)
 
 function callWebalizerGetTraffic($logfile, $outputdir, $caption, $usersdomainlist)
 {
-	global $settings, $cronlog;
+	global $settings, $cronlog, $theme;
 	$returnval = 0;
 
 	if(file_exists($settings['system']['logfiles_directory'] . $logfile . '-access.log'))
@@ -291,80 +291,3 @@ function callWebalizerGetTraffic($logfile, $outputdir, $caption, $usersdomainlis
 
 	return floatval($returnval);
 }
-
-/**
- * This function saves the logfile written by mod_log_sql
- * into a logfile webalizer can parse
- *
- * @param string $domain        The "speciallogfile" - domain(s)
- * @param string $loginname     The loginname of the customer
- * @return bool
- *
- * @author Florian Aders <eleras@syscp.org>
- */
-
-function safeSQLLogfile($domains, $loginname)
-{
-	global $db, $settings;
-	$sql = "SELECT * FROM access_log ";
-	$where = "WHERE virtual_host = ";
-
-	if(!is_array($domains))
-	{
-		// If it isn't an array, it's a speciallogfile-domain
-
-		$logname = $settings['system']['logfiles_directory'] . $loginname . '-' . $domains . '-access.log';
-		$where.= "'$domains' OR virtual_host = 'www.$domains'";
-	}
-	else
-	{
-		// If we have an array, these are all domains aggregated into a single logfile
-
-		if(count($domains) == 0)
-		{
-			// If the $omains-array is empty, this customer has only speciallogfile-
-			// domains, so just return, all logfiles are already written to disk
-
-			return true;
-		}
-
-		$logname = $settings['system']['logfiles_directory'] . $loginname . '-access.log';
-
-		// Build the "WHERE" - part of the sql-query
-
-		foreach($domains as $domain)
-		{
-			// A domain may be reached with or without the "www" in front.
-
-			$where.= "'$domain' OR virtual_host = 'www.$domain' OR virtual_host = ";
-		}
-
-		$where = substr($where, 0, -19);
-	}
-
-	// We want clean, ordered logfiles
-
-	$sql.= $where . " ORDER BY time_stamp;";
-	$logs = $db->query($sql);
-
-	// Don't overwrite the logfile - append the new stuff
-
-	file_put_contents($logname, "", FILE_APPEND);
-
-	while($logline = $db->fetch_array($logs))
-	{
-		// Create a "CustomLog" - line
-
-		$writelog = $logline['remote_host'] . " " . $logline['virtual_host'] . " " . $logline['remote_user'] . " ";
-		$writelog.= date("[d/M/Y:H:i:s O]", $logline['time_stamp']);
-		$writelog.= " \"" . $logline['request_method'] . " " . $logline['request_uri'] . " " . $logline['request_protocol'] . "\" ";
-		$writelog.= $logline['status'];
-		$writelog.= " " . $logline['bytes_sent'] . " \"" . $logline['referer'] . "\" \"" . $logline['agent'] . "\"\n";
-		file_put_contents($logname, $writelog, FILE_APPEND);
-	}
-
-	// Remove the just written stuff
-
-	$db->query("DELETE FROM access_log " . $where);
-	return true;
-}
