@@ -19,7 +19,7 @@
  * report about diskusage for customers
  */
 $result = $db->query("SELECT
-	`c`.`customerid`, `c`.`adminid`, `c`.`name`, `c`.`firstname`, `c`.`diskspace`, 
+	`c`.`customerid`, `c`.`adminid`, `c`.`name`, `c`.`firstname`, `c`.`company`, `c`.`diskspace`,
 	`c`.`diskspace_used`, `c`.`email`, `c`.`def_language`, 
 	`a`.`name` AS `adminname`, `a`.`email` AS `adminmail`
 	FROM `" . TABLE_PANEL_CUSTOMERS . "` AS `c`
@@ -35,28 +35,38 @@ while($row = $db->fetch_array($result))
 		&& (($row['diskspace_used'] * 100) / $row['diskspace']) >= (int)$settings['system']['report_webmax']
 	) {
 
+		$rep_userinfo = array(
+			'name' => $row['name'],
+			'firstname' => $row['firstname'],
+			'company' => $row['company']
+		);
 		$replace_arr = array(
-			'NAME' => $row['name'],
+			'SALUTATION' => getCorrectUserSalutation($rep_userinfo),
+			'NAME' => $row['name'], // < keep this for compatibility
 			'DISKAVAILABLE' => round(($row['diskspace'] / 1024), 2), /* traffic is stored in KB, template uses MB */
 			'DISKUSED' => round($row['diskspace_used'] / 1024, 2), /* traffic is stored in KB, template uses MB */
 			'USAGE_PERCENT' => round(($row['diskspace_used'] * 100) / $row['diskspace'], 2),
 			'MAX_PERCENT' => $settings['system']['report_webmax']
 		);
 
-		$lngfile = $db->query_first("SELECT `file` FROM `" . TABLE_PANEL_LANGUAGE . "`
-									WHERE `language` ='" . $row['def_language'] . "'");
+		$lngfile = $db->query_first("
+			SELECT `file` FROM `" . TABLE_PANEL_LANGUAGE . "`
+			WHERE `language` ='" . $row['def_language'] . "'
+		");
 
-		if($lngfile !== NULL)
-		{
+		if ($lngfile !== null) {
 			$langfile = $lngfile['file'];
-		}
-		else
-		{
-			$lngfile = $db->query_first("SELECT `file` FROM `" . TABLE_PANEL_LANGUAGE . "`
-										WHERE `language` ='" . $settings['panel']['standardlanguage'] . "'");
+		} else {
+			$lngfile = $db->query_first("
+				SELECT `file` FROM `" . TABLE_PANEL_LANGUAGE . "`
+				WHERE `language` ='" . $settings['panel']['standardlanguage'] . "'
+			");
 			$langfile = $lngfile['file'];
 		}
 
+		// include english language file (fallback)
+		include_once makeCorrectFile($pathtophpfiles . '/lng/english.lng.php');
+		// include admin/customer language file
 		include_once makeCorrectFile($pathtophpfiles . '/' . $langfile);
 
 		// Get mail templates from database; the ones from 'admin' are fetched for fallback
@@ -76,7 +86,7 @@ while($row = $db->fetch_array($result))
 
 		$_mailerror = false;
 		try {
-			$mail->SetFrom($row['email'], $row['firstname'] . " " . $row['name']);
+			$mail->SetFrom($row['adminmail'], $row['adminname']);
 			$mail->Subject = $mail_subject;
 			$mail->AltBody = $mail_body;
 			$mail->MsgHTML(nl2br($mail_body));
